Knowledge Graph
===============

Table of Contents:

* :ref:`schemas`
* :ref:`resolvers`
* :ref:`views`
* :ref:`storages`
* :ref:`files`
* :ref:`resources`

.. _schemas:

Schemas
-------

.. automodule:: nexussdk.schemas
  :members:

.. _resolvers:

Resolvers
---------

.. automodule:: nexussdk.resolvers
  :members: create, create_, fetch, fetch_, list, list_, update, update_, tag, tag_, deprecate, deprecate_

.. _views:

Views
-----

.. automodule:: nexussdk.views
  :members:

.. _storages:

Storages
--------

.. automodule:: nexussdk.storages
  :members:

.. _files:

Files
-----

.. automodule:: nexussdk.files
  :members:

.. _resources:

Resources
---------

.. automodule:: nexussdk.resources
  :members:
